==> libtunepimp-0.2.0.tar.gz: libtunepimp-0.2.0/include/track.h <==
/*----------------------------------------------------------------------------

   libtunepimp -- The MusicBrainz tagging library.  
                  Let a thousand taggers bloom!
   
   Copyright (C) Robert Kaye 2003
   
   This file is part of libtunepimp.

   libtunepimp is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   libtunepimp is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with libtunepimp; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   $Id: track.h,v 1.17 2003/06/23 09:27:19 robert Exp $

----------------------------------------------------------------------------*/
#ifndef __TRACK_H__
#define __TRACK_H__

#include <string>
using namespace std;

#include "mutex.h"
#include "metadata.h"
#include "filelookup.h"

enum FileStatus
{
    eUnrecognized = 0,     // unrecognized
    eRecognized = 1,       // Recognized and previously saved
    ePending = 2,          // pending trm calculation
    eTRMLookup = 3,        // trm done, pending trm lookup
    eTRMCollision = 4,        // trm done, pending trm lookup
    eFileLookup = 5,       // trm done, no matches, pending file lookup
    eUserSelection = 6,    // file lookup done, needs user selection
    eVerified = 7,         // User verified, about to write changes to disk 
    eDeleted = 8,          // to be deleted, waiting for refcount == 0
    eError = 9             // Error
};

class Track
{
    public:

                 Track(void) { sim = 0; changed = false; };
        virtual ~Track(void) { deleteResults(); };

        FileStatus getStatus        (void)                    { return status; };
        void       setStatus        (const FileStatus status) { this->status = status; };

        void       getFileName      (string &fileName)        { fileName = this->fileName; };
        void       setFileName      (const string &fileName)  { this->fileName = fileName; };
 
        void       getTRM           (string &trm)             { trm = this->trm; };
        void       setTRM           (const string &trm);

        void       getLocalMetadata (Metadata &mdata)         { mdata = local; };
        void       setLocalMetadata (const Metadata &mdata);

        void       getServerMetadata(Metadata &mdata)         { mdata = server; };
        void       setServerMetadata(const Metadata &mdata);

        void       getError         (string &error)           { error = this->error; };
        void       setError         (const string &error)     { this->error = error; };
        
        int        getSimilarity    (void)                    { return sim; };
        bool       hasChanged       (void)                    { return changed; };

        void       setResults       (const LookupFile::Result &type, const vector<TPResult *> &results)
                                                              { deleteResults();
                                                                lookupType = type;
                                                                lookupResult = results; };
        void       getResults       (LookupFile::Result &type, vector<TPResult *> &results)
                                                              { type = lookupType;
                                                                results = lookupResult; };

        void       lock             (void);
        void       unlock           (void);

    private:

        void       deleteResults    (void)
                   { 
                       vector<TPResult *>::iterator i;
                       for(i = lookupResult.begin(); i != lookupResult.begin(); i++)
                           delete *i;
                       lookupResult.clear();
                   };

        FileStatus         status;
        string             fileName;
        string             trm;
        Metadata           local, server;
        string             error;
        bool               changed;
        int                sim;
        Mutex              mutex;
        vector<TPResult *> lookupResult;
        LookupFile::Result lookupType;
};

#endif

==> libtunepimp-0.2.1.tar.gz: libtunepimp-0.2.1/include/track.h <==
/*----------------------------------------------------------------------------

   libtunepimp -- The MusicBrainz tagging library.  
                  Let a thousand taggers bloom!
   
   Copyright (C) Robert Kaye 2003
   
   This file is part of libtunepimp.

   libtunepimp is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   libtunepimp is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with libtunepimp; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   $Id: track.h,v 1.19 2003/07/03 08:52:49 robert Exp $

----------------------------------------------------------------------------*/
#ifndef __TRACK_H__
#define __TRACK_H__

#include <string>
using namespace std;

#include "mutex.h"
#include "metadata.h"
#include "filelookup.h"

class Track
{
    public:

                 Track(void) { sim = 0; changed = false; };
        virtual ~Track(void) { deleteResults(); };

        TPFileStatus getStatus        (void)                    { return status; };
        void       setStatus        (const TPFileStatus status) { this->status = status; };

        void       getFileName      (string &fileName)        { fileName = this->fileName; };
        void       setFileName      (const string &fileName)  { this->fileName = fileName; };
 
        void       getTRM           (string &trm)             { trm = this->trm; };
        void       setTRM           (const string &trm);

        void       getLocalMetadata (Metadata &mdata)         { mdata = local; };
        void       setLocalMetadata (const Metadata &mdata);

        void       getServerMetadata(Metadata &mdata)         { mdata = server; };
        void       setServerMetadata(const Metadata &mdata);

        void       getError         (string &error)           { error = this->error; };
        void       setError         (const string &error)     { this->error = error; };
        
        int        getSimilarity    (void)                    { return sim; };
        bool       hasChanged       (void)                    { return changed; };

        void       setResults       (const TPResultType &type, 
                                     const vector<TPResult *> &results)
                                                              { deleteResults();
                                                                lookupType = type;
                                                                lookupResult = results; };
        void       getResults       (TPResultType &type, vector<TPResult *> &results)
                                                              { type = lookupType;
                                                                results = lookupResult; };

        void       lock             (void);
        void       unlock           (void);

    private:

        void       deleteResults    (void)
                   { 
                       vector<TPResult *>::iterator i;
                       for(i = lookupResult.begin(); i != lookupResult.begin(); i++)
                           delete *i;
                       lookupResult.clear();
                   };

        TPFileStatus         status;
        string             fileName;
        string             trm;
        Metadata           local, server;
        string             error;
        bool               changed;
        int                sim;
        Mutex              mutex;
        vector<TPResult *> lookupResult;
        TPResultType       lookupType;
};

#endif
